@@ -36,10 +36,16 @@
 import re
 import libxml2
 import os
-import md5
 import sys
+try:
+    # Hashlib is new in Python 2.5
+    from hashlib import md5 as md5_new
+except ImportError:
+    from md5 import new as md5_new
 
-class docbookXmlMode:
+from basic import basicXmlMode
+
+class docbookXmlMode(basicXmlMode):
     """Class for special handling of DocBook document types.
 
     It sets lang attribute on article elements, and adds translators
@@ -73,17 +79,13 @@ class docbookXmlMode:
             'userinput'
             ]
 
-    def getTreatedAttributes(self):
-        "Returns array of tag attributes which content is to be translated"
-        return []
-
     def getStringForTranslators(self):
         """Returns string which will be used to credit translators."""
         return "translator-credits"
 
     def getCommentForTranslators(self):
         """Returns a comment to be added next to string for crediting translators."""
-        return """Put one translator per line, in the form of NAME <EMAIL>, YEAR1, YEAR2."""
+        return """Put one translator per line, in the form of NAME <EMAIL>, YEAR1, YEAR2"""
 
     def _find_articleinfo(self, node):
         if node.name == 'articleinfo' or node.name == 'bookinfo':
@@ -109,7 +111,7 @@ class docbookXmlMode:
         return last
 
     def _md5_for_file(self, filename):
-        hash = md5.new()
+        hash = md5_new()
         input = open(filename, "rb")
         read = input.read(4096)
         while read:
